python\_package package
=======================

Submodules
----------

python\_package.setup module
----------------------------

.. automodule:: odsbox.setup
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: odsbox
   :members:
   :undoc-members:
   :show-inheritance:
